<?php  
// Custom Column Component
/*
 * ======================================================================================================================
 * Copyright:        Copyright (c) 2010 Nagios Enterprises, LLC.
 * Authors:          Mike Guthrie
 * License:          GPL v2
==================================================================================================================
 *
 * LICENSE:
 *
 * This work is made available to you under the terms of Version 2 of
 * the GNU General Public License. A copy of that license should have
 * been provided with this software, but in any event can be obtained
 * from http://www.fsf.org.
 *
 * This work is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 or visit their web page on the internet at
 * http://www.fsf.org.
 *
 *
 * CONTRIBUTION POLICY:
 *
 * (The following paragraph is not intended to limit the rights granted
 * to you to modify and distribute this software under the terms of
 * licenses that may apply to the software.)
 *
 * Contributions to this software are subject to your understanding and acceptance of
 * the terms and conditions of the Nagios Contributor Agreement, which can be found
 * online at:
 *
 * http://www.nagios.com/legal/contributoragreement/
 *
 *
 * DISCLAIMER:
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
 * INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
 * PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM FOR DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
 * GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, STRICT LIABILITY, TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) OR OTHER ACTION, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

require_once(dirname(__FILE__).'/../componenthelper.inc.php');

// respect the name
$customcolumn_component_name="customcolumn";

// run the initialization function
customcolumn_component_init();

////////////////////////////////////////////////////////////////////////
// COMPONENT INIT FUNCTIONS
////////////////////////////////////////////////////////////////////////

function customcolumn_component_init(){
	global $customcolumn_component_name;
	
	$versionok=customcolumn_component_checkversion();
	
	$desc=_("This component addes a custom column to the host and service status tables.");
	if(!$versionok)
		$desc="<b>"._("Error: This component requires Nagios XI 2012R1.3 or later.")."</b>";
	
	$args=array(

		// need a name
		COMPONENT_NAME => $customcolumn_component_name,
		
		// informative information
		COMPONENT_AUTHOR => "Mike Guthrie, Nagios Enterprises, LLC",
		COMPONENT_DESCRIPTION => $desc,
		COMPONENT_TITLE => "Custom Column",
		COMPONENT_DATE => '12/03/2012',
		COMPONENT_VERSION => '1.0.1',
		// configuration function (optional)
		//COMPONENT_CONFIGFUNCTION => "customcolumn_component_config_func",
		);
		
	register_component($customcolumn_component_name,$args);
		
	//add custom table header and table data to table
	if($versionok ) {
		register_callback(CALLBACK_CUSTOM_TABLE_HEADERS,'customcolumn_component_table_header');
		register_callback(CALLBACK_CUSTOM_TABLE_DATA,'customcolumn_component_table_data'); 
	}
}		


///////////////////////////////////////////////////////////////////////////////////////////
// MISC FUNCTIONS
///////////////////////////////////////////////////////////////////////////////////////////

/**
*	adds a custom table header to the main status tables
*	@param string $cbtype: the callback name being referenced: CALLBACK_CUSTOM_TABLE_ICONS
*	@param mixed $args: the callback data array, contains all host/service data, also used to pass data back up to it
*/ 
function customcolumn_component_table_header($cbtype='',&$args=array()) {
		
	//array_dump($args); 
	$type=grab_array_var($args,'objecttype',OBJECTTYPE_HOST); 
	$x = grab_array_var($args,'object_data',null); 

	//we only want host notes for now...
	if($type==OBJECTTYPE_SERVICE)
		return; //do nothing 
		
	//html to be added to the status table icon
	$headerdata = "<th class='customheader'>Notes</th>";

	//send the html data back to the callback data array
	$args['table_headers'][] = $headerdata; 
}


/**
*	adds a custom table header to the main status tables
*	@param string $cbtype: the callback name being referenced: CALLBACK_CUSTOM_TABLE_ICONS
*	@param mixed $args: the callback data array, contains all host/service data, also used to pass data back up to it
*/ 
function customcolumn_component_table_data($cbtype='',&$args=array()) {
		
	//array_dump($args); 
	$type=grab_array_var($args,'objecttype',OBJECTTYPE_HOST); 
	$id = grab_array_var($args,'object_id',null); 
	$allow_html = grab_array_var($args,'allow_html',false); 
	//full status data as XML for selected object, access like $x->current_state. Be sure to use typecasting with XML properties.  
	$x = grab_array_var($args,'object_data',null); 
	
	//we only want host notes for now...
	if($type==OBJECTTYPE_SERVICE)
		return; //do nothing 

	$note = strval($x->notes);
		
	//html tags allowed?
	$note = $allow_html ? $note : htmlentities($note); 
	
	//html to be added to the status table data
	$tabledata = "<td class='customdata'>{$notes}</td>";

	//send the html data back to the callback data array
	$args['table_data'][] = $tabledata; 
}


/**
*	make sure we will actually work and we're not REALLY old
*/ 
function customcolumn_component_checkversion(){

	if(!function_exists('get_product_release'))
		return false;
	//requires greater than 2009R1.4B
	if(get_product_release()<301)
		return false;

	return true;
	}